@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 
-plan tests => 13;
+plan tests => 18;
 
 can_ok('main', 'remember');
 can_ok('main', 'recall');
@@ -11,9 +11,18 @@ remember foo => 1;
 remember bar => 2;
 remember baz => 3;
 
+remember_these qux => 4;
+remember_these qux => 5;
+remember_these qux => 6;
+
 is(recall 'foo', 1, 'recalled foo is 1');
 is(recall 'bar', 2, 'recalled bar is 2');
 is(recall 'baz', 3, 'recalled baz is 3');
+is_deeply([@{recall('qux')}], [ 4, 5, 6 ], 'recalled qux is [ 4, 5, 6 ]');
+
+my $bar = recall_and_update { $_++ } 'bar';
+is($bar, 2, 'recall_and_update returned 2');
+is(recall 'bar', 3, 'recall_and_update changed bar to 3');
 
 forget 'bar';
 forget 'bar'; # forgetting something twice is redundant, but ok
@@ -38,8 +47,6 @@ remember [ foo => 1, bar => 2, baz => 3 ], {
     excellent => 8,
 };
 
-is_deeply(recall [ foo => 1, bar => 2, baz => 3 ], {
-    fantastic => 10,
-    supreme   => 9,
-    excellent => 8,
-}, 'long key 1 => long value');
+is(recall [ foo => 1, bar => 2, baz => 3, 'fantastic' ], 10, 'fantastic => 10');
+is(recall [ foo => 1, bar => 2, baz => 3, 'supreme' ], 9, 'supreme => 9');
+is(recall [ foo => 1, bar => 2, baz => 3, 'excellent' ], 8, 'excellent => 8');
